@@ -8,6 +8,7 @@ from glob import glob
 from typing import Union, List, Any
 from urllib import parse
 
+from selenium.common.exceptions import NoAlertPresentException
 from selenium.webdriver.chrome.webdriver import WebDriver
 from selenium.webdriver.remote.webelement import WebElement
 
@@ -19,11 +20,10 @@ from .driver_element import DriverElement, execute_driver_find
 class DriverPage(object):
     """DriverPage封装了页面操作的常用功能，使用selenium来获取、解析、操作网页"""
 
-    def __init__(self, driver: WebDriver, timeout: float = 10):  # , locs=None
+    def __init__(self, driver: WebDriver, timeout: float = 10):
         """初始化函数，接收一个WebDriver对象，用来操作网页"""
         self._driver = driver
         self.timeout = timeout
-        # self._locs = locs
         self._url = None
         self._url_available = None
 
@@ -210,13 +210,25 @@ class DriverPage(object):
             new_y = y or self.driver.get_window_size()['height']
             self.driver.set_window_size(new_x, new_y)
 
-    def is_downloading(self, download_path: str = None) -> bool:
-        if download_path:
-            p = download_path
-        else:
-            try:
-                p = OptionsManager().get_value('chrome_options', 'experimental_options')['prefs'][
-                    'download.default_directory']
-            except IOError('No download path found.'):
-                raise
-        return not glob(f'{p}\\*.crdownload')
+    def chrome_downloading(self, download_path: str) -> list:
+        """检查下载情况"""
+        return glob(f'{download_path}\\*.crdownload')
+
+    def process_alert(self, mode: str = 'ok', text: str = None) -> Union[str, None]:
+        """处理提示框
+        :param mode: 'ok' 或 'cancel'，若输入其它值，不会按按钮但依然返回文本值
+        :param text: 处理prompt提示框时可输入文本
+        :return:
+        """
+        try:
+            alertObject = self.driver.switch_to.alert
+        except NoAlertPresentException:
+            return None
+        if text:
+            alertObject.send_keys(text)
+        text = alertObject.text
+        if mode == 'cancel':
+            alertObject.dismiss()
+        elif mode == 'ok':
+            alertObject.accept()
+        return text
